




# PBSA : Proximity Based Survival Analysis

Due to some uncertain cause we had to retract the package, this will bw made avaialble after December,2024.

[![Documentation Status](https://readthedocs.org/projects/pbsa/badge/?version=latest)](https://pbsa.readthedocs.io/en/latest/?badge=latest)



![PBSA](Population.png)





Proximity Based Survival Analysis are algorithms, designed for survival prediction
using proximity information. The k-NN survival, Random Survival Forest, Kernel Survival
are some examples of proximity based survival analysis. While this package tends 
to provide those algorithms later, currently the package provides the following algorithms:

- COBRA Survival 

For now other algorithms are taken from scikit-survival and np_survival to provide as
a base learner for the ensemble algorithms.

## installation

```
pip install proxsurv
```

The documentation is available at [https://pbsa.readthedocs.io/en/latest/](https://pbsa.readthedocs.io/en/latest/)

